@@ -20,7 +20,6 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
   nthread <- xgb.params$nthread
 
 
-
   for (var in missing.vars) {
     na.idx <- Na.idx[[var]]
     obs.y <- yobs.list[[var]]
@@ -58,8 +57,6 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
     }
 
 
-
-
     obs.data <- All.m[-na.idx, , drop = FALSE]
     mis.data <- All.m[na.idx, , drop = FALSE]
 
@@ -189,10 +186,10 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
           obj.type <- "binary:logistic"
         }
         xgb.params$objective <- obj.type
-        xgb.params$eval_metric<- "logloss"
+        xgb.params$eval_metric <- "logloss"
         xgb.params$num_class <- NULL
         xgb.fit <- xgb.train(
-          data = dobs,  evals = evals,
+          data = dobs, evals = evals,
           params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
           print_every_n = print_every_n, verbose = verbose, ...
         )
@@ -205,7 +202,6 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
         xgb.models[[var]] <- filedir
 
 
-
         if (is.null(pmm.type) | isTRUE(pmm.type == "auto")) {
           # for pmm.type=NULL or "auto"
           yhatmis <- ifelse(yhatmis >= 0.5, 1, 0)
@@ -260,10 +256,10 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
           obj.type <- "binary:logistic"
         }
         xgb.params$objective <- obj.type
-        xgb.params$eval_metric<- "logloss"
+        xgb.params$eval_metric <- "logloss"
         xgb.params$num_class <- NULL
         xgb.fit <- xgb.train(
-          data = dobs,  evals = evals,
+          data = dobs, evals = evals,
           params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
           print_every_n = print_every_n, verbose = verbose, ...
         )
@@ -313,9 +309,9 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
         obj.type <- "multi:softprob"
       }
       xgb.params$objective <- obj.type
-      xgb.params$eval_metric<- "mlogloss"
+      xgb.params$eval_metric <- "mlogloss"
       N.class <- length(levels(sorted.dt[[var]]))
-      xgb.params$num_class = N.class
+      xgb.params$num_class <- N.class
 
       xgb.fit <- xgb.train(
         data = dobs,
@@ -358,8 +354,6 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
   # for extra variables---------------------------------------------------------------------------------------------
 
 
-
-
   if (!is.null(extra.vars)) {
     if (matrix.method == "as.matrix") {
       All.m <- as.matrix(sorted.dt)
@@ -387,9 +381,6 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
     }
 
 
-
-
-
     for (var in extra.vars) {
       # features <- setdiff(sorted.names, var)
       # form <- reformulate(termlabels = features, response = var)
@@ -407,7 +398,6 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
       obs.data <- All.m[, -var.idx, drop = FALSE]
 
 
-
       if (extra.types[var] == "numeric" | extra.types[var] == "integer") {
         dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
 
@@ -466,7 +456,7 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
             obj.type <- "binary:logistic"
           }
           xgb.params$objective <- obj.type
-          xgb.params$eval_metric<- "logloss"
+          xgb.params$eval_metric <- "logloss"
           xgb.params$num_class <- NULL
           xgb.fit <- xgb.train(
             data = dobs, evals = evals,
@@ -514,10 +504,10 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
             obj.type <- "binary:logistic"
           }
           xgb.params$objective <- obj.type
-          xgb.params$eval_metric<- "logloss"
+          xgb.params$eval_metric <- "logloss"
           xgb.params$num_class <- NULL
           xgb.fit <- xgb.train(
-            data = dobs,  evals = evals,
+            data = dobs, evals = evals,
             params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
             print_every_n = print_every_n, verbose = verbose, ...
           )
@@ -551,9 +541,9 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
           obj.type <- "multi:softprob"
         }
         xgb.params$objective <- obj.type
-        xgb.params$eval_metric<- "mlogloss"
+        xgb.params$eval_metric <- "mlogloss"
         N.class <- length(levels(sorted.dt[[var]]))
-        xgb.params$num_class = N.class
+        xgb.params$num_class <- N.class
 
         xgb.fit <- xgb.train(
           data = dobs,
