@@ -1,10 +1,9 @@
 # A function use to obtain yhatobs using the whole dataset (use for pmm.type=1)
 save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
                          yobs.list, maxit, pmm.link, sorted.dt, missing.vars, extra.vars = NULL, extra.types = NULL, sorted.names, Na.idx, missing.types, Ncol,
-                         xgb.params=list(),
-                         nrounds , early_stopping_rounds , print_every_n , verbose,
+                         xgb.params = list(),
+                         nrounds, early_stopping_rounds, print_every_n, verbose,
                          ...) {
-
   nthread <- xgb.params$nthread
   # param xgb.params NULL if XGBmodels was fed in
   # return a list of yhatobs values for specified variables
@@ -22,56 +21,47 @@ save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
   # general case : save all variables with NAs
   for (i in seq_len(maxit)) {
     for (var in missing.vars) {
-      #features <- setdiff(sorted.names, var)
-      #form <- reformulate(termlabels = features, response = var)
+      # features <- setdiff(sorted.names, var)
+      # form <- reformulate(termlabels = features, response = var)
 
       na.idx <- Na.idx[[var]]
       obs.y <- yobs.list[[var]]
 
-      Mis.vars<-missing.vars[missing.vars != var]
+      Mis.vars <- missing.vars[missing.vars != var]
 
       if (length(obs.y) == 1) {
         warning(paste("PMM to this dataset may not be sensible as there is only one observed entry in the variable ", var, sep = ""))
       }
 
 
-      if(matrix.method=="as.matrix"){
-
-        Mis.m<-as.matrix(sorted.dt[,Mis.vars,with = FALSE])
-
-
-      }else{
-
-        Mis.list <- lapply(Mis.vars, function(feature){
-
-          if(cbind.types[feature] %in% c("numeric","integer")){
+      if (matrix.method == "as.matrix") {
+        Mis.m <- as.matrix(sorted.dt[, Mis.vars, with = FALSE])
+      } else {
+        Mis.list <- lapply(Mis.vars, function(feature) {
+          if (cbind.types[feature] %in% c("numeric", "integer")) {
             as.matrix(sorted.dt[[feature]])
-          } else if(cbind.types[feature] == "ordered"){
-            Matrix::t(fac2Sparse(sorted.dt[[feature]], factorPatt12=c(T,F), contrasts.arg = "contr.poly")[[1]])
+          } else if (cbind.types[feature] == "ordered") {
+            Matrix::t(fac2Sparse(sorted.dt[[feature]], factorPatt12 = c(T, F), contrasts.arg = "contr.poly")[[1]])
           } else {
             Matrix::t(fac2sparse(sorted.dt[[feature]]))[, -1, drop = FALSE]
           }
         })
 
 
-        if(matrix.method=="cpp.combo"){
-          Mis.m<-cbind_combo(Mis.list )
-        }else if(matrix.method=="cpp.factor"){
-          Mis.m<-cbind_sparse_matrix(Mis.list )
+        if (matrix.method == "cpp.combo") {
+          Mis.m <- cbind_combo(Mis.list)
+        } else if (matrix.method == "cpp.factor") {
+          Mis.m <- cbind_sparse_matrix(Mis.list)
         }
-
-
       }
 
-      All.m<-cbind2(Mis.m,Obs.m)
-
-      obs.data<-All.m[-na.idx, , drop = FALSE]
-      mis.data<-All.m[na.idx, , drop = FALSE]
+      All.m <- cbind2(Mis.m, Obs.m)
 
+      obs.data <- All.m[-na.idx, , drop = FALSE]
+      mis.data <- All.m[na.idx, , drop = FALSE]
 
 
       if (missing.types[var] == "numeric") {
-
         dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
         dmis <- xgb.DMatrix(data = mis.data, nthread = nthread)
 
@@ -96,14 +86,13 @@ save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
 
         if (i != maxit) {
           yhatmis <- predict(xgb.fit, dmis)
-          #sorted.dt[[var]][na.idx] <- yhatmis
+          # sorted.dt[[var]][na.idx] <- yhatmis
           sorted.dt[na.idx, (var) := yhatmis]
         } else {
           # last iteration
           yhatobs.list[[var]] <- predict(xgb.fit, dobs)
         }
-      }else if (missing.types[var] == "integer") {
-
+      } else if (missing.types[var] == "integer") {
         dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
         dmis <- xgb.DMatrix(data = mis.data, nthread = nthread)
 
@@ -128,12 +117,12 @@ save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
 
         if (i != maxit) {
           yhatmis <- predict(xgb.fit, dmis)
-          #sorted.dt[[var]][na.idx] <- yhatmis
+          # sorted.dt[[var]][na.idx] <- yhatmis
           # round to integer
           sorted.dt[na.idx, (var) := round(yhatmis)]
         } else {
           # last iteration
-          #yhatobs is not rounded as yhatmis is not rounded when pmm is used
+          # yhatobs is not rounded as yhatmis is not rounded when pmm is used
           yhatobs.list[[var]] <- predict(xgb.fit, dobs)
         }
       } else if (missing.types[var] == "binary") {
@@ -166,7 +155,6 @@ save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
 
           msg <- paste("The binary variable", var, "in the data only have single class. Imputation models can't be built.")
           stop(msg)
-
         } else {
           # general case
           if (pmm.link == "logit") {
@@ -178,7 +166,7 @@ save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
           }
 
           xgb.params$objective <- obj.type
-          xgb.params$eval_metric<- "logloss"
+          xgb.params$eval_metric <- "logloss"
           xgb.params$num_class <- NULL
           xgb.fit <- xgb.train(
             data = dobs, evals = evals,
@@ -191,14 +179,13 @@ save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
             # if pmm.link="logit", these would be logit values, otherwise would be probability values
             if (pmm.link == "logit") {
               # if prediction is logit
-              yhatmis  <- exp(yhatmis) / (1 + exp(yhatmis))
+              yhatmis <- exp(yhatmis) / (1 + exp(yhatmis))
             }
             yhatmis <- ifelse(yhatmis >= 0.5, 1, 0)
             yhatmis <- levels(sorted.dt[[var]])[yhatmis + 1]
             sorted.dt[na.idx, (var) := yhatmis]
-
           } else {
-            #last iteration
+            # last iteration
             yhatobs.list[[var]] <- predict(xgb.fit, dobs)
           }
         }
@@ -224,14 +211,12 @@ save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
           if (i != maxit) {
             yhatmis <- as.logical(names(bin.t[1]))
             sorted.dt[na.idx, (var) := yhatmis]
-
           } else {
             yhatobs.list[[var]] <- rep(as.logical(names(bin.t[1])), length(obs.y))
           }
 
           msg <- paste("The logical variable", var, "in the data only have single class. Imputation models can't be built.")
           stop(msg)
-
         } else {
           # general case
           if (pmm.link == "logit") {
@@ -242,7 +227,7 @@ save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
             obj.type <- "binary:logistic"
           }
           xgb.params$objective <- obj.type
-          xgb.params$eval_metric<- "logloss"
+          xgb.params$eval_metric <- "logloss"
           xgb.params$num_class <- NULL
           xgb.fit <- xgb.train(
             data = dobs, evals = evals,
@@ -255,12 +240,12 @@ save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
             # if pmm.link="logit", these would be logit values, otherwise would be probability values
             if (pmm.link == "logit") {
               # if prediction is logit
-              yhatmis<- exp(yhatmis) / (1 + exp(yhatmis))
+              yhatmis <- exp(yhatmis) / (1 + exp(yhatmis))
             }
             yhatmis <- ifelse(yhatmis >= 0.5, T, F)
             sorted.dt[na.idx, (var) := yhatmis]
           } else {
-            #last iteration
+            # last iteration
             yhatobs.list[[var]] <- predict(xgb.fit, dobs)
           }
         }
@@ -269,7 +254,7 @@ save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
         obs.y <- as.integer(obs.y) - 1
         yobs.list[[var]] <- obs.y
 
-        dobs <-xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
+        dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
         dmis <- xgb.DMatrix(data = mis.data, nthread = nthread)
 
         if (is.null(early_stopping_rounds)) {
@@ -288,10 +273,10 @@ save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
           obj.type <- "multi:softprob"
         }
         xgb.params$objective <- obj.type
-        xgb.params$eval_metric<- "mlogloss"
+        xgb.params$eval_metric <- "mlogloss"
 
         N.class <- length(levels(sorted.dt[[var]]))
-        xgb.params$num_class = N.class
+        xgb.params$num_class <- N.class
         xgb.fit <- xgb.train(
           data = dobs,
           evals = evals,
@@ -320,54 +305,46 @@ save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
 
   if (!is.null(extra.vars)) {
     # if there are extra.vars, use the sorted.dt after the last iteration to obtain models
-    if(matrix.method=="as.matrix"){
-
-      All.m<-as.matrix(sorted.dt)
-
-    }else{
-
-      All.list <- lapply(sorted.names, function(feature){
-
-        if(cbind.types[feature] %in% c("numeric","integer")){
+    if (matrix.method == "as.matrix") {
+      All.m <- as.matrix(sorted.dt)
+    } else {
+      All.list <- lapply(sorted.names, function(feature) {
+        if (cbind.types[feature] %in% c("numeric", "integer")) {
           as.matrix(sorted.dt[[feature]])
-        } else if(cbind.types[feature] == "ordered"){
-          Matrix::t(fac2Sparse(sorted.dt[[feature]], factorPatt12=c(T,F), contrasts.arg = "contr.poly")[[1]])
+        } else if (cbind.types[feature] == "ordered") {
+          Matrix::t(fac2Sparse(sorted.dt[[feature]], factorPatt12 = c(T, F), contrasts.arg = "contr.poly")[[1]])
         } else {
           Matrix::t(fac2sparse(sorted.dt[[feature]]))[, -1, drop = FALSE]
         }
       })
 
 
-      if(matrix.method=="cpp.combo"){
-        All.m<-cbind_combo(All.list )
-      }else if(matrix.method=="cpp.factor"){
-        All.m<-cbind_sparse_matrix(All.list )
+      if (matrix.method == "cpp.combo") {
+        All.m <- cbind_combo(All.list)
+      } else if (matrix.method == "cpp.factor") {
+        All.m <- cbind_sparse_matrix(All.list)
       }
 
-      Ncol.list<-lapply(All.list,ncol)
-      end.idx<-cumsum(Ncol.list)
-      start.idx<-c(1,(end.idx+1)[-length(end.idx)])
+      Ncol.list <- lapply(All.list, ncol)
+      end.idx <- cumsum(Ncol.list)
+      start.idx <- c(1, (end.idx + 1)[-length(end.idx)])
     }
 
 
-
     for (var in extra.vars) {
-
-
       obs.y <- yobs.list[[var]]
 
-      if(matrix.method=="as.matrix"){
-        var.idx<-all.idx[var]
-      }else{
-        v<-all.idx[var]
-        var.idx<-start.idx[v]:end.idx[v]
+      if (matrix.method == "as.matrix") {
+        var.idx <- all.idx[var]
+      } else {
+        v <- all.idx[var]
+        var.idx <- start.idx[v]:end.idx[v]
       }
 
-      obs.data<-All.m[, -var.idx , drop = FALSE]
+      obs.data <- All.m[, -var.idx, drop = FALSE]
 
 
       if (extra.types[var] == "numeric" | extra.types[var] == "integer") {
-
         dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
 
         if (is.null(early_stopping_rounds)) {
@@ -389,7 +366,6 @@ save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
           print_every_n = print_every_n, verbose = verbose, ...
         )
         yhatobs.list[[var]] <- predict(xgb.fit, dobs)
-
       } else if (extra.types[var] == "binary") {
         obs.y <- as.integer(obs.y) - 1
         bin.t <- sort(table(obs.y))
@@ -417,7 +393,7 @@ save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
             obj.type <- "binary:logistic"
           }
           xgb.params$objective <- obj.type
-          xgb.params$eval_metric<- "logloss"
+          xgb.params$eval_metric <- "logloss"
           xgb.params$num_class <- NULL
           xgb.fit <- xgb.train(
             data = dobs, evals = evals,
@@ -456,10 +432,10 @@ save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
             obj.type <- "binary:logistic"
           }
           xgb.params$objective <- obj.type
-          xgb.params$eval_metric<- "logloss"
+          xgb.params$eval_metric <- "logloss"
           xgb.params$num_class <- NULL
           xgb.fit <- xgb.train(
-            data = dobs,  evals = evals,
+            data = dobs, evals = evals,
             params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
             print_every_n = print_every_n, verbose = verbose, ...
           )
@@ -471,7 +447,7 @@ save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
         obs.y <- as.integer(obs.y) - 1
         yobs.list[[var]] <- obs.y
 
-        dobs <-xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
+        dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
         if (is.null(early_stopping_rounds)) {
           evals <- list(train = dobs)
         } else {
@@ -479,14 +455,14 @@ save_yhatobs <- function(Obs.m, matrix.method, cbind.types, all.idx,
           # to be done, have eval
           # evals <- list(train = dobs,eval=dmis)
         }
-          #save probability as yhatobs to do pmm matching
+        # save probability as yhatobs to do pmm matching
 
         obj.type <- "multi:softprob"
         xgb.params$objective <- obj.type
-        xgb.params$eval_metric<- "mlogloss"
+        xgb.params$eval_metric <- "mlogloss"
 
         N.class <- length(levels(sorted.dt[[var]]))
-        xgb.params$num_class = N.class
+        xgb.params$num_class <- N.class
 
         xgb.fit <- xgb.train(
           data = dobs,
